use core::panic;
use mongodb::{Client, options::{ClientOptions, Credential}};
mod packet;
use packet::Packet;
use std::time;

#[tokio::main]
async fn main() {
    // Parse a connection string into an options struct.
    let mut client_options = ClientOptions::parse("mongodb://localhost:27017").await.unwrap();

    // Manually set an option.
    client_options.app_name = Some("My App".to_string());
    client_options.credential = Some(Credential::default());
    client_options.credential.as_mut().unwrap().username = Some(std::env::var("mongo_username").unwrap());
    client_options.credential.as_mut().unwrap().password = Some(std::env::var("mongo_password").unwrap());
    
    // Get a handle to the deployment.
    let client = Client::with_options(client_options).unwrap();

    let db = client.database("test");
    
    match db.create_collection("test", None).await {
        Err(_) => panic!("ERROR: incorrect usage"),
        _ => {}
    } 
    let collection = db.collection::<Packet>("test");

    loop {
        collection.insert_one(Packet{ 
            time: time::SystemTime::now(), 
            text: format!("Current Unix time: {:?}", time::SystemTime::now().duration_since(time::UNIX_EPOCH).unwrap())
        }, None).await.unwrap();
    }
}